@@ -1,5 +1,5 @@
 package App::GitGot::Command::fork;
-$App::GitGot::Command::fork::VERSION = '1.29'; # TRIAL
+$App::GitGot::Command::fork::VERSION = '1.31'; # TRIAL
 # ABSTRACT: fork a github repo
 use 5.014;
 
@@ -19,7 +19,8 @@ use namespace::autoclean;
 sub options {
   my( $class , $app ) = @_;
   return (
-    [ 'noclone|n' => 'FIXME' ] ,
+    [ 'noclone|n'     => 'If set, do not check out a local working copy of the forked repo' ] ,
+    [ 'noremoteadd|N' => 'If set, do not add the forked repo as the "upstream" repo in the new working copy' ] ,
   );
 }
 
@@ -53,6 +54,12 @@ sub _execute {
   if ( ! $self->opt->noclone ) {
     say "Cloning into $path" unless $self->quiet;
     $new_repo->clone( $resp->{ssh_url} );
+
+    if ( ! $self->opt->noremoteadd ) {
+      say "Adding '$github_url' as remote 'upstream'..."
+        unless $self->quiet;
+      $new_repo->remote( add => upstream => $github_url );
+    }
   }
 
   $self->add_repo( $new_repo );
@@ -111,7 +118,7 @@ App::GitGot::Command::fork - fork a github repo
 
 =head1 VERSION
 
-version 1.29
+version 1.31
 
 =head1 SYNOPSIS
 
